@@ -1,62 +1,65 @@
 /*
  *  avisplit.c
  *
- *  Copyright (C) Thomas streich - June 2001
+ *  Copyright (C) Thomas Oestreich - June 2001
  *
  *  This file is part of transcode, a video stream processing tool
- *      
+ *
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2, or (at your option)
  *  any later version.
- *   
+ *
  *  transcode is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- *   
+ *
  *  You should have received a copy of the GNU General Public License
  *  along with GNU Make; see the file COPYING.  If not, write to
- *  the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. 
+ *  the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  */
 
+#include "transcode.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include "limits.h"
 #include <string.h>
 #include "buffer.h"
-#include "avilib.h"
-#include "config.h"
-#include "transcode.h"
-#include "framecode.h"
-#include "aud_scan.h"
+#include "avilib/avilib.h"
+#include "libtc/framecode.h"
+#include "aud_scan_avi.h"
 
 #define EXE "avisplit"
 #define MBYTE (1<<20)
 
-void version()
+/* AVI_info is no longer in avilib */
+void AVI_info(avi_t *avifile);
+
+void version(void)
 {
   printf("%s (%s v%s) (C) 2001-2003 Thomas Oestreich,"
-                        " 2003-2008 Transcode Team\n",
-                          EXE, PACKAGE, VERSION);
+                        " 2003-2009 Transcode Team\n",
+                        EXE, PACKAGE, VERSION);
 }
 
-void usage(int status)
+static void usage(int status)
 {
     version();
     printf("\nUsage: %s [options]\n", EXE);
-    printf("\t -i name             file name\n");
-    printf("\t -s size             de-chunk based on size in MB (0=dechunk)\n");
-    printf("\t -H n                split only first n chunks [all]\n");
-    printf("\t -t s1-s2[,s3-s4,..] de-chunk based on time/framecode (n:m:l.k) [off]\n");
-    printf("\t -c                  merge chunks on-the-fly for option -t [off]\n");
-    printf("\t -m                  force split at upper limit for option -t [off]\n");
-    printf("\t -o base             split to base-%%04d.avi [name-%%04d]\n");
-    printf("\t -b n                handle vbr audio [autodetect]\n");
-    printf("\t -f FILE             read AVI comments from FILE [off]\n");
-    printf("\t -v                  print version\n");
+    printf("    -i name             file name\n");
+    printf("    -s size             de-chunk based on size in MB (0=dechunk)\n");
+    printf("    -H n                split only first n chunks [all]\n");
+    printf("    -t s1-s2[,s3-s4,..] de-chunk based on time/framecode (n:m:l.k) [off]\n");
+    printf("    -c                  merge chunks on-the-fly for option -t [off]\n");
+    printf("    -m                  force split at upper limit for option -t [off]\n");
+    printf("    -o base             split to base-%%04d.avi [name-%%04d]\n");
+    printf("    -b n                handle vbr audio [autodetect]\n");
+    printf("    -f FILE             read AVI comments from FILE [off]\n");
+    printf("    -v                  print version\n");
     exit(status);
 }
 
@@ -89,7 +92,7 @@ int main(int argc, char *argv[])
   char *codec;
 
   int j, n, key, k;
-  
+
   int key_boundary=1;
 
   int chunk=0, is_open, ch, split_next=INT_MAX;
@@ -124,29 +127,29 @@ int main(int argc, char *argv[])
 
   char separator[] = ",";
 
-  tc_memcpy_init(0, -1);
+  ac_init(AC_ALL);
 
   if(argc==1) usage(EXIT_FAILURE);
   memset(byte_count_at_start, 0 , sizeof(long)*AVI_MAX_TRACKS);
-  
+
   while ((ch = getopt(argc, argv, "b:mco:vs:i:f:t:H:?h")) != -1) {
 
     switch (ch) {
 
     case 'b':
-      
+
       if(optarg[0]=='-') usage(EXIT_FAILURE);
       is_vbr = atoi(optarg);
-      
+
       if(is_vbr<0) usage(EXIT_FAILURE);
-      
+
       break;
-      
+
     case 'c':  // cat
       single_output_file = out_file;
       break;
 
-    case 'm': 
+    case 'm':
 	key_boundary = 0;
       break;
 
@@ -162,14 +165,14 @@ int main(int argc, char *argv[])
   	  break;
 
     case 'i':
-  
+
       if(optarg[0]=='-') usage(EXIT_FAILURE);
       in_file=optarg;
-  
+
       break;
-  
+
     case 's':
-  
+
       if(optarg[0]=='-') usage(EXIT_FAILURE);
       chunk = atoi(optarg);
       split_option=SPLIT_BY_SIZE;
@@ -183,17 +186,17 @@ int main(int argc, char *argv[])
       break;
 
     case 'o':
-  
+
       if(optarg[0]=='-') usage(EXIT_FAILURE);
       base = optarg;
-  
+
       break;
 
     case 'f':
-      
+
       if(optarg[0]=='-') usage(EXIT_FAILURE);
       comfile = optarg;
-      
+
       break;
 
     case 'v':
@@ -225,7 +228,7 @@ int main(int argc, char *argv[])
     break;
   }
 
-  
+
   // open file
   if(NULL == (in = AVI_open_input_file(in_file,1))) {
     AVI_print_error("AVI open");
@@ -235,7 +238,7 @@ int main(int argc, char *argv[])
   // read video info;
 
   AVI_info(in);
- 
+
   // read video info;
 
   frames =  AVI_video_frames(in);
@@ -248,10 +251,10 @@ int main(int argc, char *argv[])
   chan   =  AVI_audio_channels(in);
   bits   =  AVI_audio_bits(in);
 
-  for (k = 0; k<AVI_MAX_TRACKS; k++) 
+  for (k = 0; k<AVI_MAX_TRACKS; k++)
       aud_ms[k] = 0.0;
 
-  for (k = 0; k<AVI_MAX_TRACKS; k++) 
+  for (k = 0; k<AVI_MAX_TRACKS; k++)
       aud_ms_w[k] = 0.0;
 
   switch (split_option) {
@@ -268,25 +271,25 @@ int main(int argc, char *argv[])
     if(frames<=0) frames=INT_MAX;
 
     for (n=0; n<frames; ++n) {
-      
+
       // read video frame
       bytes = AVI_read_frame(in, data, &key);
-      
+
       if(bytes < 0) {
         fprintf(stderr, "%d (%ld)\n", n, bytes);
         AVI_print_error("AVI read video frame");
         break;
       }
-      
+
       //check for closing outputfile
-	
+
       if(key && is_open && n && split_next) {
-	    
+
         size = AVI_bytes_written(out);
         fsize = ((double) size)/MBYTE;
-	    
-        if((size + MBYTE) > (uint64_t)(chunk*MBYTE)) {      
-		
+
+        if((size + MBYTE) > (uint64_t)(chunk*MBYTE)) {
+
           // limit exceeded, close file
 
           fprintf(stderr, "\n");
@@ -316,27 +319,27 @@ int main(int argc, char *argv[])
 
 	  return (0);
       }
-      
+
       // need new output file
       if(!is_open) {
 
 	  if(base == NULL || strlen(base)==0) {
-          snprintf(out_file, sizeof(out_file), "%s-%04d", in_file, j);
+          tc_snprintf(out_file, sizeof(out_file), "%s-%04d", in_file, j);
         } else {
-          snprintf(out_file, sizeof(out_file), "%s-%04d.avi", base, j);
+          tc_snprintf(out_file, sizeof(out_file), "%s-%04d.avi", base, j);
         }
 
         // prepare output file
-    
+
         if(NULL == (out = AVI_open_output_file(out_file))) {
           AVI_print_error("AVI open");
           exit(1);
         }
-    
+
         AVI_set_video(out, width, height, fps, codec);
 	if (comfile!=NULL)
 	    AVI_set_comment_fd(out, open(comfile, O_RDONLY));
-    
+
         for(k=0; k< AVI_audio_tracks(in); ++k) {
 
           AVI_set_audio_track(in, k);
@@ -348,7 +351,7 @@ int main(int argc, char *argv[])
           format =  AVI_audio_format(in);
           mp3rate=  AVI_audio_mp3rate(in);
 
-    
+
           //set next track of output file
           AVI_set_audio_track(out, j);
           AVI_set_audio(out, chan, rate, bits, format, mp3rate);
@@ -357,14 +360,14 @@ int main(int argc, char *argv[])
 
         is_open=1;
       }
-    
+
       //write frame
-    
+
       if(AVI_write_frame(out, data, bytes, key)<0) {
         AVI_print_error("AVI write video frame");
         return(-1);
       }
-    
+
       vid_chunks++;
       vid_ms = vid_chunks*1000.0/fps;
 
@@ -375,7 +378,7 @@ int main(int argc, char *argv[])
         AVI_set_audio_track(out, k);
 
 	sync_audio_video_avi2avi(vid_ms, &aud_ms[k], in, out);
-      } 
+      }
 
     }//process all frames
 
@@ -411,9 +414,9 @@ int main(int argc, char *argv[])
     if( single_output_file != NULL ) {
 
       if(base == NULL || strlen(base)==0) {
-        snprintf(out_file, sizeof(out_file), "%s-%04d", in_file, j++ );
+        tc_snprintf(out_file, sizeof(out_file), "%s-%04d", in_file, j++ );
       } else {
-        snprintf(out_file, sizeof(out_file), "%s", base );
+        tc_snprintf(out_file, sizeof(out_file), "%s", base );
       }
       if( ( out = AVI_open_output_file( out_file ) ) == NULL ) {
         AVI_print_error( "AVI open" );
@@ -487,10 +490,10 @@ int main(int argc, char *argv[])
          * prepare output file
          */
         if( base == NULL || strlen( base ) == 0 ) {
-          snprintf( out_file, sizeof(out_file), "%s-%04d", in_file, j++ );
+          tc_snprintf( out_file, sizeof(out_file), "%s-%04d", in_file, j++ );
         }
         else {
-          snprintf( out_file, sizeof(out_file), "%s-%04d", base, j++ );
+          tc_snprintf( out_file, sizeof(out_file), "%s-%04d", base, j++ );
         }
 
         if( ( out = AVI_open_output_file( out_file ) ) == NULL ) {
@@ -550,9 +553,9 @@ int main(int argc, char *argv[])
 
 	  double tms = aud_ms[k];
 	  AVI_set_audio_track( in, k );
-	  
+
 	  byte_count_audio[ k ] = AVI_get_audio_position_index(in);
-	 
+
 	  if (!didread) {
 	    sync_audio_video_avi2avi_ro (vid_ms, &aud_ms[k], in);
 	  }
@@ -567,7 +570,7 @@ int main(int argc, char *argv[])
 
 	}
         /*
-         * if one of the preferred frames write frame (video+audio) 
+         * if one of the preferred frames write frame (video+audio)
          * but don't stop until the next keyframe
          */
         if( n >= ttime->stf && ( n <= ttime->etf || ( n >= ttime->stf && ! key ) ) ) {
@@ -599,7 +602,7 @@ int main(int argc, char *argv[])
              * re-read video and audio from rewound position
              */
             bytes = AVI_read_frame( in, data, &key );
-	    
+
 	    // count the frame which will be written also this, too
 	    vid_ms = vid_ms_w+1000.0/fps;
 
@@ -641,12 +644,12 @@ int main(int argc, char *argv[])
 	    if( n > ttime->etf && key ) {
 		printf( "\n" );
 		break;
-	    }       
+	    }
 	} else {
 	    if( n > ttime->etf) {
 		printf( "\n" );
 		break;
-	    }        
+	    }
 	}
       }
       /*
@@ -683,3 +686,14 @@ int main(int argc, char *argv[])
 }
 
 
+/*************************************************************************/
+
+/*
+ * Local variables:
+ *   c-file-style: "stroustrup"
+ *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
+ *   indent-tabs-mode: nil
+ * End:
+ *
+ * vim: expandtab shiftwidth=4:
+ */
